@@ -56,7 +56,7 @@ print
 	grep { warn scalar @$_ }
 	[
 		# for module
-		map  { sprintf "%-9s => '%s' %s,\n", grep { defined } @$_{'pause', 'name', 'email'} }
+		map  { sprintf "%-9s => '%s',\n", grep { defined } @$_{'pause', 'name', 'email'} }
 		sort { $a->{'pause'} cmp $b->{'pause'} }
 		
 		# for list
@@ -66,28 +66,34 @@ print
 		#~ map  { qq{"$_->{'pause'}" $_->{'email'}\n} }
 		#~ grep { $_->{'email'} && $_->{'email'} !~ /CENSORED/ && $_->{'email'} !~ /\.ru$/ }
 		
-		#~ # cpan author
-		#~ grep { $_->{'author'} }
+		# cpan author
+		grep { $_->{'author'} }
 		
 		#~ # not cpan author, have pause id
-		#~ grep {!$_->{'author'} }
+		# grep {!$_->{'author'} }
 		
-		#~ # exclude
-		#~ grep { $_->{'pause'} !~ /^VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
+		# ru
+		grep { $_->{'pause'} eq 'STEALTHY' and $_->{'author'}=0; 1}
+		grep { $_->{'pause'} !~ /^CUB|DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
 		
-		#~ grep { $_->{'email'} !~ /ua$/ }
-		#~ grep { $_->{'email'} !~ /bg$/ }
-		#~ grep { $_->{'email'} !~ /by$/ }
-		#~ grep { $_->{'email'} !~ /ws$/ }
-		#~ grep { $_->{'email'} !~ /cz$/ }
+		grep { $_->{'email'} !~ /ua$/ }
+		grep { $_->{'email'} !~ /bg$/ }
+		grep { $_->{'email'} !~ /by$/ }
+		grep { $_->{'email'} !~ /ws$/ }
+		grep { $_->{'email'} !~ /cz$/ }
 		
 		# ua
-		grep { $_->{'pause'} =~ /^VTI|GUGU|EJS|GRUBER|MVUETS$/ || $_->{'email'} =~ /ua$/ }
+		# grep { $_->{'pause'} =~ /^CUB|VTI|GUGU|EJS|GRUBER|MVUETS|DARKNOS|DZHARIY$/ || $_->{'email'} =~ /ua$/ }
 		
 		grep {
-			my $name = $_->{'name'};
-			scalar grep { $name =~ /$_/ } @$NAME;
-		}
+				my $name = $_->{'name'};
+				scalar grep { $name =~ /$_/ } @$NAME;
+			}
+		
+		# no
+		# grep { $_->{pause} !~ /^BDULFER$/ }
+		# grep { $_->{pause} =~ /^KJETIL|SJN|MRAMBERG|KRN|ANDREMAR|TRONDMM|ARNE|EIDOLON|NICOMEN|COSIMO|AFF|ESPIZO$/ || $_->{'email'} =~ /no$/ }
+		
 		map  {
 			my($url,  $name ) = $_->[ 1] =~ /<a href="([^"]+)">([^<]+)/; $name  ||= $_->[ 1]; $name =~ s/\s+$//; $name =~ s/&[^;]+;//sg;
 			my($url2, $pause) = $_->[-1] =~ /<a href="([^"]+)">([^<]+)/; $pause ||= $_->[-1];
